package com.zanxiang.game.module.manage.rpc.impl;

import com.zanxiang.game.module.base.pojo.dto.SendMsgDto;
import com.zanxiang.game.module.base.rpc.SendMsgRpc;
import com.zanxiang.game.module.manage.enums.MsgTaskStatusEnum;
import com.zanxiang.game.module.manage.enums.MsgTaskTypeEnum;
import com.zanxiang.game.module.manage.service.ISendMsgTaskService;
import com.zanxiang.game.module.mybatis.entity.SendMsgTask;
import com.zanxiang.module.util.pojo.ResultVO;
import lombok.extern.slf4j.Slf4j;
import org.apache.dubbo.config.annotation.DubboService;

import javax.annotation.Resource;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.ZoneId;

@DubboService
@Slf4j
public class SendMsgImpl implements SendMsgRpc {

    @Resource
    private ISendMsgTaskService sendMsgTaskService;

    @Override
    public ResultVO<Boolean> sendMsg(SendMsgDto sendMsgDto) {
        try {
            // 数据校验
            if (sendMsgDto == null || sendMsgDto.getMsg() == null || sendMsgDto.getGameId() == null || sendMsgDto.getCreateBy() == null || sendMsgDto.getRoles() == null || sendMsgDto.getRoles().isEmpty()) {
                return ResultVO.fail("参数不能为空");
            }
            //创建任务
            SendMsgTask sendMsgTask = createSendMsgTask(sendMsgDto);
            //保存任务
            sendMsgTaskService.save(sendMsgTask);
            //todo：发送消息
            log.info("发送消息成功");
            return ResultVO.ok();
        } catch (Exception e) {
            log.error("发送消息异常, sendMsgDto : {}, e : {}", sendMsgDto, e.getMessage());
            return ResultVO.fail("发送消息异常");
        }
    }

    private SendMsgTask createSendMsgTask(SendMsgDto dto) {
        SendMsgTask sendMsgTask = new SendMsgTask();
        sendMsgTask.setMsg(dto.getMsg());
        sendMsgTask.setRoleIdCount((long) dto.getRoles().size());
        sendMsgTask.setTaskName(dto.getTaskName());
        sendMsgTask.setTaskCondition(dto.getSendConditionJson());
        sendMsgTask.setGameId(dto.getGameId());
        //任务类型
        sendMsgTask.setType(MsgTaskTypeEnum.IMMEDIATE_TASK.getName());
        //任务状态
        sendMsgTask.setStatus(MsgTaskStatusEnum.WAIT_SEND.getName());
        sendMsgTask.setCreateBy(dto.getCreateBy());
        sendMsgTask.setCreateTime(LocalDateTime.now(ZoneId.of("UTC")));
        sendMsgTask.setUpdateTime(LocalDateTime.now(ZoneId.of("UTC")));
        return sendMsgTask;
    }
}
